#ifndef __CSCINTILLA_INC__
#define __CSCINTILLA_INC__


// include standard scintilla constants and structures
#ifndef __SCINTILLA_INC__
#include "scintilla.inc"
#endif

#ifndef __SCILEXER_INC__
#include "scilexer.inc"
#endif

#typedef COLORREF unsigned int
#typedef BOOL     int

class CScintilla
{
	declare CScintilla();
	declare Attach(HWND hwndSci),HWND;
	declare SetText(string* text);

	// Text retrieval and modification
	declare SciGetText(int length, string *text),int;
	declare SciSetText(string *text),int;
	declare SetSavePoint(),int;
	declare GetLine(int line, char *text),int;
	declare ReplaceSel(string *text),int;
	declare SetReadOnly(bool readOnly),int;
	declare GetReadOnly(),BOOL;
	declare GetTextRange(TextRange *tr),int;
	declare Allocate(int bytes),int;
	declare AddText(int length, string *s),int;
	declare AddStyledText(int length, cell *s),int;
	declare AppendText(int length, string *s),int;
	declare InsertText(int pos, string *text),int;
	declare ClearAll(),int;
	declare ClearDocumentStyle(),int;
	declare GetCharAt(int position),int;
	declare GetStyleAt(int pos),int;
	declare GetStyledText(TextRange *tr),int;
	declare SetStyleBits(int bits),int;
	declare GetStyleBits(),int;
	// GTK+-specific: Access to encoded text
	declare TargetAsUTF8(string *s),int;
	declare EncodedFromUTF8(string *utf8, string *encoded),int;
	declare SetLengthForEncode(int bytes),int;
	// Searching
	declare FindText(int flags, TextToFind *ttf),int;
	declare SearchAnchor(),int;
	declare SearchNext(int searchFlags, string *text),int;
	declare SearchPrev(int searchFlags, string *text),int;
	// Search and replace using the target
	declare SetTargetStart(int pos),int;
	declare GetTargetStart(),int;
	declare SetTargetEnd(int pos),int;
	declare GetTargetEnd(),int;
	declare TargetFromSelection(),int;
	declare SetSearchFlags(int searchFlags),int;
	declare GetSearchFlags(),int;
	declare SearchInTarget(int length, string *text),int;
	declare ReplaceInTarget(int length, string *text),int;
	declare ReplaceTargetRe(int length, string *text),int;
	// Overtype
	declare SetOverType(BOOL overType),int;
	declare GetOverType(),BOOL;
	// Cut, copy and paste
	declare SciCut(),int;
	declare SciCopy(),int;
	declare SciPaste(),int;
	declare SciClear(),int;
	declare CanPaste(),BOOL;
	declare CopyRange(int start, int end),int;
	declare CopyText(int length, string *text),int;
	declare SetPasteConvertEndings(BOOL convert),int;
	declare GetPasteConvertEndings(),BOOL;
	// Error handling
	declare SetStatus(int status),int;
	declare GetStatus(),int;
	// Undo and Redo
	declare Undo(),int;
	declare CanUndo(),BOOL;
	declare EmptyUndoBuffer(),int;
	declare Redo(),int;
	declare CanRedo(),BOOL;
	declare SetUndoCollection(BOOL collectUndo),int;
	declare GetUndoCollection(),BOOL;
	declare BeginUndoAction(),int;
	declare EndUndoAction(),int;
	// Selection and information
	declare GetTextLength(),int;
	declare GetLength(),int;
	declare GetLineCount(),int;
	declare GetFirstVisibleLine(),int;
	declare LinesOnScreen(),int;
	declare GetModify(),int;
	declare SetSel(int anchorPos, int currentPos),int;
	declare GotoPos(int pos),int;
	declare GotoLine(int line),int;
	declare SetCurrentPos(int position),int;
	declare GetCurrentPos(),int;
	declare SetAnchor(int pos),int;
	declare GetAnchor(),int;
	declare SetSelectionStart(int position),int;
	declare GetSelectionStart(),int;
	declare SetSelectionEnd(int position),int;
	declare GetSelectionEnd(),int;
	declare SelectAll(),int;
	declare LineFromPosition(int position),int;
	declare PositionFromLine(int line),int;
	declare GetLineEndPosition(int line),int;
	declare LineLength(int line),int;
	declare GetColumn(int position),int;
	declare FindColumn(int line, int column),int;
	declare PositionFromPoint(int x, int y),int;
	declare PositionFromPointClose(int x, int y),int;
	declare PointXFromPosition(int position),int;
	declare PointYFromPosition(int position),int;
	declare HideSelection(BOOL hide),int;
	declare GetSelText(string *text),int;
	declare GetCurLine(int textLen,string *text),int;
	declare SelectionIsRectangle(),int;
	declare SetSelectionMode(int mode),int;
	declare GetSelectionMode(),int;
	declare GetLineSelStartPosition(int line),int;
	declare GetLineSelEndPosition(int line),int;
	declare MoveCaretInsideView(),int;
	declare WordEndPosition(int position, BOOL onlyWordCharacters),int;
	declare WordStartPosition(int position, BOOL onlyWordCharacters),int;
	declare PositionBefore(int position),int;
	declare PositionAfter(int position),int;
	declare TextWidth(int styleNumber, string *text),int;
	declare TextHeight(int line),int;
	declare ChooseCaretX(),int;
	// Scrolling and automatic scrolling
	declare LineScroll(int column, int line),int;
	declare ScrollCaret(),int;
	declare SetXCaretPolicy(int caretPolicy, int caretSlop),int;
	declare SetYCaretPolicy(int caretPolicy, int caretSlop),int;
	declare SetVisiblePolicy(int caretPolicy, int caretSlop),int;
	declare SetHScrollBar(BOOL visible),int;
	declare GetHScrollBar(),BOOL;
	declare SetVScrollBar(BOOL visible),int;
	declare GetVScrollBar(),BOOL;
	declare GetXOffset(),int;
	declare SetXOffset(int xOffset),int;
	declare SetScrollWidth(int pixelWidth),int;
	declare GetScrollWidth(),int;
	declare SetEndAtLastLine(BOOL endAtLastLine),int;
	declare GetEndAtLastLine(),BOOL;
	// White space
	declare SetViewWS(int wsMode),int; // SCWS_INVISIBLE,SCWS_VISIBLEALWAYS,SCWS_VISIBLEAFTERINDENT
	declare GetViewWS(),int;
	declare SetWhiteSpaceFore(BOOL useWhitespaceForeColour,COLORREF colour),int;
	declare SetWhiteSpaceBack(bool useWhitespaceBackColour,COLORREF colour),int;
	// Cursor
	declare SciSetCursor(int curType),int;
	declare SciGetCursor(),int;
	// Mouse capture
	declare SetMouseDownCaptures(BOOL captures),int;
	declare GetMouseDownCaptures(),BOOL;
	// Line endings
	declare SetEolMode(int eolMode),int;
	declare GetEolMode(),int;
	declare ConvertEols(int eolMode),int; // SC_EOL_CRLF,SC_EOL_CR,SC_EOL_LF
	declare SetViewEol(BOOL visible),int;
	declare GetViewEol(),BOOL;
	// Styling
	declare GetEndStyled(),int;
	declare StartStyling(int pos, int mask),int;
	declare SetStyling(int length, int style),int;
	declare SetStylingEx(int length, string *styles),int;
	declare SetLineState(int line, int value),int;
	declare GetLineState(int line),int;
	declare GetMaxLineState(),int;
	// Style definition
	declare StyleResetDefault(),int;
	declare StyleClearAll(),int;
	declare StyleSetFont(int styleNumber,string *fontName),int;
	declare StyleSetSize(int styleNumber, int sizeInPoints),int;
	declare StyleSetBold(int styleNumber, BOOL bold),int;
	declare StyleSetItalic(int styleNumber, BOOL italic),int;
	declare StyleSetUnderline(int styleNumber, BOOL underline),int;
	declare StyleSetFore(int styleNumber,COLORREF colour),int;
	declare StyleSetBack(int styleNumber,COLORREF colour),int;
	declare StyleSetEolFilled(int styleNumber, BOOL eolFilled),int;
	declare StyleSetCharacterSet(int styleNumber, int charSet),int;
	declare StyleSetCase(int styleNumber, int caseMode),int; // SC_CASE_UPPER, SC_CASE_LOWER, SC_CASE_MIXED
	declare StyleSetVisible(int styleNumber, BOOL visible),int;
	declare StyleSetChangeable(int styleNumber, bool changeable),int;
	declare StyleSetHotSpot(int styleNumber, BOOL hotspot),int;
	// Caret, selection, and hotspot styles
	declare SetSelFore(BOOL useSelectionForeColour,COLORREF colour),int;
	declare SetSelBack(BOOL useSelectionBackColour,COLORREF colour),int;
	declare SetCaretFore(COLORREF colour),int;
	declare GetCaretFore(),COLORREF;
	declare SetCaretLineVisible(BOOL show),int;
	declare GetCaretLineVisible(),BOOL;
	declare SetCaretLineBack(COLORREF colour),int;
	declare GetCaretLineBack(),COLORREF;
	declare SetCaretLineBackAlpha(int alpha),int;
	declare GetCaretLineBackAlpha(),int;
	declare SetCaretPeriod(int milliseconds),int;
	declare GetCaretPeriod(),int;
	declare SetCaretWidth(int pixels),int;
	declare GetCaretWidth(),int;
	declare SetHotSpotActiveFore(BOOL useHotSpotForeColour,COLORREF colour),int;
	declare SetHotSpotActiveBack(BOOL useHotSpotBackColour,COLORREF colour),int;
	declare SetHotSpotActiveUnderline(BOOL underline),int;
	declare SetHotSpotSingleLine(BOOL singleLine),int;
	declare SetControlCharSymbol(int symbol),int;
	declare GetControlCharSymbol(),int;
	declare SetCaretSticky(),int;
	declare GetCaretSticky(),int;
	declare ToggleCaretSticky(),int;
	// Margins
	declare SetMarginTypeN(int margin, int iType),int;
	declare GetMarginTypeN(int margin),int;
	declare SetMarginWidthN(int margin, int pixelWidth),int;
	declare GetMarginWidthN(int margin),int;
	declare SetMarginMaskN(int margin, int mask),int;
	declare GetMarginMaskN(int margin),int;
	declare SetMarginSensitiveN(int margin, BOOL sensitive),int;
	declare GetMarginSensitiveN(int margin),int;
	declare SetMarginLeft(int pixels),int;
	declare GetMarginLeft(),int;
	declare SetMarginRight(int pixels),int;
	declare GetMarginRight(),int;
	declare SetFoldMarginColor(BOOL useSetting,COLORREF colour),int;
	declare SetFoldMarginHiColor(BOOL useSetting,COLORREF colour),int;
	// Other settings
	declare SetUsePalette(BOOL allowPaletteUse),int;
	declare GetUsePalette(),BOOL;
	declare SetBufferedDraw(BOOL isBuffered),int;
	declare GetBufferedDraw(),BOOL;
	declare SetTwoPhaseDraw(BOOL twoPhase),int;
	declare GetTwoPhaseDraw(),BOOL;
	declare SetCodePage(int codePage),int;
	declare GetCodePage(),int;
	declare SetWordChars(string *chars),int;
	declare SetWhitespaceChars(string *chars),int;
	declare SetCharsDefault(),int;
	declare GrabFocus(),int;
	declare SciSetFocus(BOOL focus),int;
	declare SciGetFocus(),BOOL;
	// Brace highlighting
	declare BraceHighLight(int pos1, int pos2),int;
	declare BraceBadLight(int pos1),int;
	declare BraceMatch(int position, int maxReStyle),int;
	// Tabs and Indentation Guides
	declare SetTabWidth(int widthInChars),int;
	declare GetTabWidth(),int;
	declare SetUseTabs(BOOL useTabs),int;
	declare GetUseTabs(),BOOL;
	declare SetIndent(int widthInChars),int;
	declare GetIndent(),int;
	declare SetTabIndents(BOOL tabIndents),int;
	declare GetTabIndents(),BOOL;
	declare SetBackspaceUnindents(BOOL bsUnIndents),int;
	declare GetBackspaceUnindents(),BOOL;
	declare SetLineIndentation(int line, int indentation),int;
	declare GetLineIndentation(int line),int;
	declare GetLineIndentPosition(int line),int;
	declare SetIndentationGuides(BOOL view),int;
	declare GetIndentationGuides(),BOOL;
	declare SetHighlightGuide(int column),int;
	declare GetHighlightGuide(),int;
	// Markers
	declare MarkerDefine(int markerNumber, int markerSymbols),int;
	declare MarkerDefinePixmap(int markerNumber, byte *xpm),int;
	declare MarkerSetFore(int markerNumber,COLORREF colour),int;
	declare MarkerSetBack(int markerNumber,COLORREF colour),int;
	declare MarkerAdd(int line, int markerNumber),int;
	declare MarkerAddSet(int line, int markerMask),int;
	declare MarkerDelete(int line, int markerNumber),int;
	declare MarkerDeleteAll(int markerNumber),int;
	declare MarkerGet(int line),int;
	declare MarkerNext(int lineStart, int markerMask),int;
	declare MarkerPrevious(int lineStart, int markerMask),int;
	declare MarkerLineFromHandle(int markerHandle),int;
	declare MarkerDeleteHandle(int markerHandle),int;
	// Indicators
	declare IndicSetStyle(int indicatorNumber, int indicatorStyle),int;
	declare IndicGetStyle(int indicatorNumber),int;
	declare IndicSetFore(int indicatorNumber, COLORREF colour),int;
	declare IndicGetFore(int indicatorNumber),COLORREF;
	// Autocompletion
	declare AutoCShow(int lenEntered, string *list),int;
	declare AutoCCancel(),int;
	declare AutoCActive(),int;
	declare AutoCPosStart(),int;
	declare AutoCComplete(),int;
	declare AutoCStops(string *chars),int;
	declare AutoCSetSeparator(byte separator),int;
	declare AutoCGetSeparator(),int;
	declare AutoCSelect(string *sel),int;
	declare AutoCGetCurrent(),int;
	declare AutoCSetCancelAtStart(BOOL cancel),int;
	declare AutoCGetCancelAtStart(),BOOL;
	declare AutoCSetFillups(string *chars),int;
	declare AutoCSetChooseSingle(BOOL chooseSingle),int;
	declare AutoCGetChooseSingle(),BOOL;
	declare AutoCSetIgnoreCase(BOOL ignoreCase),int;
	declare AutoCGetIgnoreCase(),BOOL;
	declare AutoCSetAutoHide(BOOL autoHide),int;
	declare AutoCGetAutoHide(),BOOL;
	declare AutoCSetDropRestOfWord(BOOL dropRestOfWord),int;
	declare AutoCGetDropRestOfWord(),BOOL;
	declare RegisterImage(),int;
	declare ClearRegisteredImages(),int;
	declare AutoCSetTypeSeparator(byte separatorCharacter),int;
	declare AutoCGetTypeSeparator(),int;
	declare AutoCSetMaxHeight(int rowCount),int;
	declare AutoCGetMaxHeight(),int;
	declare AutoCSetMaxWidth(int characterCount),int;
	declare AutoCGetMaxWidth(),int;
	// User lists
	declare UserListShow(int listType, string *list),int;
	// Call tips
	declare CallTipShow(int posStart, string *definition),int;
	declare CallTipCancel(),int;
	declare CallTipActive(),int;
	declare CallTipPosStart(),int;
	declare CallTipSetHlt(int highlightStart, int highlightEnd),int;
	declare CallTipSetBack(COLORREF colour),int;
	declare CallTipFore(COLORREF colour),int;
	declare CallTipForeHlt(COLORREF colour),int;
	declare CallTipUseStyle(int tabsize),int;
	// Keyboard commands
	declare LineDown(),int;
	declare LineDownExtend(),int;
	declare LineDownRectExtend(),int;
	declare LineScrollDown(),int;
	declare LineUp(),int;
	declare LineUpExtend(),int;
	declare LineUpRectExtend(),int;
	declare LineScrollUp(),int;
	declare ParaDown(),int;
	declare ParaDownExtend(),int;
	declare ParaUp(),int;
	declare ParaUpExtend(),int;
	declare CharLeft(),int;
	declare CharLeftExtend(),int;
	declare CharLeftRectExtend(),int;
	declare CharRight(),int;
	declare CharRightExtend(),int;
 	declare CharRightRectExtend(),int;
	declare WordLeft(),int;
	declare WordLeftExtend(),int;
	declare WordRight(),int;
	declare WordRightExtend(),int;
	declare WordLeftEnd(),int;
	declare WordLeftEndExtend(),int;
	declare WordRightEnd(),int;
	declare WordRightEndExtend(),int;
	declare WordPartLeft(),int;
	declare WordPartLeftExtend(),int;
	declare WordPartRight(),int;
	declare WordPartRightExtend(),int;
	declare Home(),int;
 	declare HomeExtend(),int;
	declare HomeRectExtend(),int;
	declare HomeDisplay(),int;
	declare HomeDisplayExtend(),int;
	declare HomeWrap(),int;
	declare HomeWrapExtend(),int;
	declare VcHome(),int;
	declare VcHomeExtend(),int;
	declare VcHomeRectExtend(),int;
	declare VcHomeWrap(),int;
	declare VcHomeWrapExtend(),int;
	declare LineEnd(),int;
	declare LineEndExtend(),int;
	declare LineEndRectExtend(),int;
	declare LineEndDisplay(),int;
	declare LineEndDisplayExtend(),int;
	declare LineEndWrap(),int;
	declare LineEndWrapExtend(),int;
	declare DocumentStart(),int;
	declare DocumentStartExtend(),int;
	declare DocumentEnd(),int;
	declare DocumentEndExtend(),int;
	declare PageUp(),int;
	declare PageUpExtend(),int;
	declare PageUpRectExtend(),int;
	declare PageDown(),int;
	declare PageDownExtend(),int;
	declare PageDownRectExtend(),int;
	declare StutteredPageUp(),int;
	declare StutteredPageUpExtend(),int;
	declare StutteredPageDown(),int;
	declare StutteredPageDownExtend(),int;
	declare DeleteBack(),int;
	declare DeleteBackNotLine(),int;
	declare DeleteWordLeft(),int;
	declare DeleteWordRight(),int;
	declare DeleteLineLeft(),int;
	declare DeleteLineRight(),int;
	declare LineDelete(),int;
	declare LineCut(),int;
	declare LineCopy(),int;
	declare LineTranspose(),int;
	declare LineDuplicate(),int;
	declare LowerCase(),int;
	declare UpperCase(),int;
	declare Cancel(),int;
	declare EditToggleOverType(),int;
	declare NewLine(),int;
	declare FormFeed(),int;
	declare Tab(),int;
	declare BackTab(),int;
	declare SelectionDuplicate(),int;
	// Key bindings
	declare AssignCmdKey(int keyDefinition, int sciCommand),int;
	declare ClearCmdKey(int keyDefinition),int;
	declare ClearAllCmdKeys(),int;
	declare SciNull(),int;
	// Popup edit menu
	declare UsePopup(bool bEnablePopup),int;
	// Macro recording
	declare StartRecord(),int;
	declare StopRecord(),int;
	// Printing
	declare FormatRange(bool bDraw, RangeToFormat *pfr),int;
	declare SetPrintMagnification(int magnification),int;
	declare GetPrintMagnification(),int;
	declare SetPrintColorMode(int mode),int;
	declare GetPrintColorMode(),int;
	declare SetPrintWrapMode(int wrapMode),int;
	declare GetPrintWrapMode(),int;
	// Direct access
	declare GetDirectFunction(),int;
	declare GetDirectPointer(),int;
	// Multiple views
	declare GetDocPointer(),pointer;
	declare SetDocPointer(pointer pDoc),int;
	declare CreateDocument(),pointer;
	declare AddRefDocument(pointer pDoc),int;
	declare ReleaseDocument(pointer pDoc),int;
	// Folding
	declare VisibleFromDocLine(int docLine),int;
	declare DocLineFromVisible(int displayLine),int;
	declare ShowLines(int lineStart, int lineEnd),int;
	declare HideLines(int lineStart, int lineEnd),int;
	declare GetLineVisible(int line),int;
	declare SetFoldLevel(int line, int level),int;
	declare GetFoldLevel(int line),int;
	declare SetFoldFlags(int flags),int;
	declare GetLastChild(int line, int level),int;
	declare GetFoldParent(int line),int;
	declare SetFoldExpanded(int line, bool expanded),int;
	declare GetFoldExpanded(int line),int;
	declare ToggleFold(int line),int;
	declare EnsureVisible(int line),int;
	declare EnsureVisibleEnforcePolicy(int line),int;
	// Line wrapping
	declare SetWrapMode(int wrapMode),int;
	declare GetWrapMode(),int;
	declare SetWrapVisualFlags(int wrapVisualFlags),int;
	declare GetWrapVisualFlags(),int;
	declare SetWrapVisualFlagsLocation(int wrapVisualFlagsLocation),int;
	declare GetWrapVisualFlagsLocation(),int;

	declare SetWrapStartIndent(int indent),int;
	declare GetWrapStartIndent(),int;
	declare SetLayoutCache(int cacheMode),int;
	declare GetLayoutCache(),int;
	declare LinesSplit(int pixelWidth),int;
	declare LinesJoin(),int;
	declare WrapCount(int docLine),int;
	// Zooming
	declare ZoomIn(),int;
	declare ZoomOut(),int;
	declare SetZoom(int zoomInPoints),int;
	declare GetZoom(),int;
	// Long lines
	declare SetEdgeMode(int mode),int;
	declare GetEdgeMode(),int;
	declare SetEdgeColumn(int column),int;
	declare GetEdgeColumn(),int;
	declare SetEdgeColor(COLORREF colour),int;
	declare GetEdgeColor(),COLORREF;
	// Lexer
	declare SetLexer(int lexer),int;
	declare GetLexer(),int;
	declare SetLexerLanguage(string *name),int;
	declare LoadLexerLibrary(string *path),int;
	declare Colorize(int start, int end),int;
	declare SetProperty(string *key, string *value),int;
	declare GetProperty(string *key, string *value),int;
	declare GetPropertyExpanded(string *key, string *value),int;
	declare GetPropertyInt(string *key, int default_),int;
	declare SetKeywords(int keyWordSet, string *keyWordList),int;
	declare GetStyleBitsNeeded(),int;
	// Notifications
	declare SetModEventMask(int eventMask),int;
	declare GetModEventMask(),int;
	declare SetMouseDwellTime(int time),int; // ??
	declare GetMouseDwellTime(),int;

	int m_hwnd;
	int m_sci_fn;
	int m_sci_ptr;
}

#endif
